@@ -47,6 +47,7 @@
 #include <sys/wait.h>
 #include <syslog.h>
 #include <unistd.h>
+#include <time.h>
 
 #include "pump.h"
 
@@ -1237,6 +1238,7 @@ char * pumpDhcpRun(char * device, int flags, int reqLease,
     unsigned char * chptr;
     time_t startTime = pumpUptime();
     int true = 1;
+    int ttl = 16;
     char * saveDeviceName;
     unsigned char messageType;
 
@@ -1260,6 +1262,10 @@ char * pumpDhcpRun(char * device, int flags, int reqLease,
 	close(s);
 	return perrorstr("setsockopt");
     }
+    if (setsockopt(s, SOL_IP, IP_TTL, &ttl, sizeof(ttl))) {
+	close(s);
+	return perrorstr("setsockopt");
+    }
 
     if (flags & PUMP_FLAG_NOCONFIG) {
 	if ((chptr = getInterfaceInfo(intf, s))) {
@@ -1321,8 +1327,11 @@ char * pumpDhcpRun(char * device, int flags, int reqLease,
 
     syslog (LOG_DEBUG, "PUMP: sending discover\n");
 
+    if (override && (override->flags & OVERRIDE_FLAG_NOBOOTP))
+      syslog (LOG_DEBUG, "PUMP: Ignoring non-DHCP BOOTP responses\n");
+ 
     if ((chptr = handleTransaction(s, override, &breq, &bresp, &broadcastAddr,
-				   NULL, 1, startTime, DHCP_TYPE_OFFER))) {
+				   NULL, (override && (override->flags & OVERRIDE_FLAG_NOBOOTP))?0:1, startTime, DHCP_TYPE_OFFER))) {
 	close(s);
 	pumpDisableInterface(intf->device);
 	return chptr;
