@@ -23,6 +23,9 @@
 #define PUMP_INTFINFO_HAS_LEASE		(1 << 7)
 #define PUMP_INTFINFO_HAS_REQLEASE	(1 << 8)
 #define PUMP_INTFINFO_HAS_NEXTSERVER	(1 << 9)
+#define PUMP_INTFINFO_NEEDS_NEWLEASE	(1 << 10)
+#define PUMP_INTFINFO_HAS_MTU           (1 << 11)
+#define PUMP_INTFINFO_HAS_PTPADDR       (1 << 12)
 
 #define PUMP_NETINFO_HAS_LOGSRVS	(1 << 15)
 #define PUMP_NETINFO_HAS_LPRSRVS	(1 << 16)
@@ -69,11 +72,17 @@ struct pumpNetIntf {
     int numXdm;
     int numDns;
     int flags;
+
+    /* these don't really belong here, but anaconda's about the only thing 
+     * that uses pump and this stuff is needed for the loader on s390 */
+    int mtu;                    
+    struct in_addr ptpaddr;             /* ptp address for ptp devs like ctc */
 };
 
 #define OVERRIDE_FLAG_NODNS		(1 << 0)
 #define OVERRIDE_FLAG_NONISDOMAIN	(1 << 1)
 #define OVERRIDE_FLAG_NOGATEWAY		(1 << 2)
+#define OVERRIDE_FLAG_NOBOOTP           (1 << 3)
 
 struct pumpOverrideInfo {
     struct pumpNetIntf intf;
